@@ -31,6 +31,8 @@ class BaseApp():
     
     app_name = ""
     app_theme = ''
+    app_icon = None
+    
     menu = None
     indexview = None
     
@@ -93,7 +95,9 @@ class BaseApp():
         if 'APP_NAME' in self.app.config:
             self.app_name = self.app.config['APP_NAME']
         else:
-            self.app_name = 'AppBuilder'
+            self.app_name = 'F.A.B.'
+        if 'APP_ICON' in self.app.config:
+            self.app_icon = self.app.config['APP_ICON']
         if 'APP_THEME' in self.app.config:
             self.app_theme = self.app.config['APP_THEME']
         else:
